#[repr(C)]pub struct VkMemoryBarrier {
pub sType: VkStructureType,
pub pNext: *const void,
pub srcAccessMask: VkAccessFlags,
pub dstAccessMask: VkAccessFlags,
}Expand description
VkMemoryBarrier
Fields
sType: VkStructureTypepNext: *const voidsrcAccessMask: VkAccessFlagsMemory accesses from the source of the dependency to synchronize
dstAccessMask: VkAccessFlagsMemory accesses from the destination of the dependency to synchronize
Implementations