#[repr(C)]pub struct VkPastPresentationTimingGOOGLE {
pub presentID: uint32_t,
pub desiredPresentTime: uint64_t,
pub actualPresentTime: uint64_t,
pub earliestPresentTime: uint64_t,
pub presentMargin: uint64_t,
}Expand description
VkPastPresentationTimingGOOGLE
Fields
presentID: uint32_tApplication-provided identifier, previously given to vkQueuePresentKHR
desiredPresentTime: uint64_tEarliest time an image should have been presented, previously given to vkQueuePresentKHR
actualPresentTime: uint64_tTime the image was actually displayed
earliestPresentTime: uint64_tEarliest time the image could have been displayed
presentMargin: uint64_tHow early vkQueuePresentKHR was processed vs. how soon it needed to be and make earliestPresentTime
Implementations