VkPhysicalDeviceVulkan13Properties

Struct VkPhysicalDeviceVulkan13Properties 

#[repr(C)]
pub struct VkPhysicalDeviceVulkan13Properties {
Show 47 fields pub sType: VkStructureType, pub pNext: *mut void, pub minSubgroupSize: uint32_t, pub maxSubgroupSize: uint32_t, pub maxComputeWorkgroupSubgroups: uint32_t, pub requiredSubgroupSizeStages: VkShaderStageFlags, pub maxInlineUniformBlockSize: uint32_t, pub maxPerStageDescriptorInlineUniformBlocks: uint32_t, pub maxPerStageDescriptorUpdateAfterBindInlineUniformBlocks: uint32_t, pub maxDescriptorSetInlineUniformBlocks: uint32_t, pub maxDescriptorSetUpdateAfterBindInlineUniformBlocks: uint32_t, pub maxInlineUniformTotalSize: uint32_t, pub integerDotProduct8BitUnsignedAccelerated: VkBool32, pub integerDotProduct8BitSignedAccelerated: VkBool32, pub integerDotProduct8BitMixedSignednessAccelerated: VkBool32, pub integerDotProduct4x8BitPackedUnsignedAccelerated: VkBool32, pub integerDotProduct4x8BitPackedSignedAccelerated: VkBool32, pub integerDotProduct4x8BitPackedMixedSignednessAccelerated: VkBool32, pub integerDotProduct16BitUnsignedAccelerated: VkBool32, pub integerDotProduct16BitSignedAccelerated: VkBool32, pub integerDotProduct16BitMixedSignednessAccelerated: VkBool32, pub integerDotProduct32BitUnsignedAccelerated: VkBool32, pub integerDotProduct32BitSignedAccelerated: VkBool32, pub integerDotProduct32BitMixedSignednessAccelerated: VkBool32, pub integerDotProduct64BitUnsignedAccelerated: VkBool32, pub integerDotProduct64BitSignedAccelerated: VkBool32, pub integerDotProduct64BitMixedSignednessAccelerated: VkBool32, pub integerDotProductAccumulatingSaturating8BitUnsignedAccelerated: VkBool32, pub integerDotProductAccumulatingSaturating8BitSignedAccelerated: VkBool32, pub integerDotProductAccumulatingSaturating8BitMixedSignednessAccelerated: VkBool32, pub integerDotProductAccumulatingSaturating4x8BitPackedUnsignedAccelerated: VkBool32, pub integerDotProductAccumulatingSaturating4x8BitPackedSignedAccelerated: VkBool32, pub integerDotProductAccumulatingSaturating4x8BitPackedMixedSignednessAccelerated: VkBool32, pub integerDotProductAccumulatingSaturating16BitUnsignedAccelerated: VkBool32, pub integerDotProductAccumulatingSaturating16BitSignedAccelerated: VkBool32, pub integerDotProductAccumulatingSaturating16BitMixedSignednessAccelerated: VkBool32, pub integerDotProductAccumulatingSaturating32BitUnsignedAccelerated: VkBool32, pub integerDotProductAccumulatingSaturating32BitSignedAccelerated: VkBool32, pub integerDotProductAccumulatingSaturating32BitMixedSignednessAccelerated: VkBool32, pub integerDotProductAccumulatingSaturating64BitUnsignedAccelerated: VkBool32, pub integerDotProductAccumulatingSaturating64BitSignedAccelerated: VkBool32, pub integerDotProductAccumulatingSaturating64BitMixedSignednessAccelerated: VkBool32, pub storageTexelBufferOffsetAlignmentBytes: VkDeviceSize, pub storageTexelBufferOffsetSingleTexelAlignment: VkBool32, pub uniformTexelBufferOffsetAlignmentBytes: VkDeviceSize, pub uniformTexelBufferOffsetSingleTexelAlignment: VkBool32, pub maxBufferSize: VkDeviceSize,
}
VkPhysicalDeviceVulkan13Properties

Fields

sType: VkStructureTypepNext: *mut voidminSubgroupSize: uint32_t

The minimum subgroup size supported by this device

maxSubgroupSize: uint32_t

The maximum subgroup size supported by this device

maxComputeWorkgroupSubgroups: uint32_t

The maximum number of subgroups supported in a workgroup

requiredSubgroupSizeStages: VkShaderStageFlags

The shader stages that support specifying a subgroup size

maxInlineUniformBlockSize: uint32_tmaxPerStageDescriptorInlineUniformBlocks: uint32_tmaxPerStageDescriptorUpdateAfterBindInlineUniformBlocks: uint32_tmaxDescriptorSetInlineUniformBlocks: uint32_tmaxDescriptorSetUpdateAfterBindInlineUniformBlocks: uint32_tmaxInlineUniformTotalSize: uint32_tintegerDotProduct8BitUnsignedAccelerated: VkBool32integerDotProduct8BitSignedAccelerated: VkBool32integerDotProduct8BitMixedSignednessAccelerated: VkBool32integerDotProduct4x8BitPackedUnsignedAccelerated: VkBool32integerDotProduct4x8BitPackedSignedAccelerated: VkBool32integerDotProduct4x8BitPackedMixedSignednessAccelerated: VkBool32integerDotProduct16BitUnsignedAccelerated: VkBool32integerDotProduct16BitSignedAccelerated: VkBool32integerDotProduct16BitMixedSignednessAccelerated: VkBool32integerDotProduct32BitUnsignedAccelerated: VkBool32integerDotProduct32BitSignedAccelerated: VkBool32integerDotProduct32BitMixedSignednessAccelerated: VkBool32integerDotProduct64BitUnsignedAccelerated: VkBool32integerDotProduct64BitSignedAccelerated: VkBool32integerDotProduct64BitMixedSignednessAccelerated: VkBool32integerDotProductAccumulatingSaturating8BitUnsignedAccelerated: VkBool32integerDotProductAccumulatingSaturating8BitSignedAccelerated: VkBool32integerDotProductAccumulatingSaturating8BitMixedSignednessAccelerated: VkBool32integerDotProductAccumulatingSaturating4x8BitPackedUnsignedAccelerated: VkBool32integerDotProductAccumulatingSaturating4x8BitPackedSignedAccelerated: VkBool32integerDotProductAccumulatingSaturating4x8BitPackedMixedSignednessAccelerated: VkBool32integerDotProductAccumulatingSaturating16BitUnsignedAccelerated: VkBool32integerDotProductAccumulatingSaturating16BitSignedAccelerated: VkBool32integerDotProductAccumulatingSaturating16BitMixedSignednessAccelerated: VkBool32integerDotProductAccumulatingSaturating32BitUnsignedAccelerated: VkBool32integerDotProductAccumulatingSaturating32BitSignedAccelerated: VkBool32integerDotProductAccumulatingSaturating32BitMixedSignednessAccelerated: VkBool32integerDotProductAccumulatingSaturating64BitUnsignedAccelerated: VkBool32integerDotProductAccumulatingSaturating64BitSignedAccelerated: VkBool32integerDotProductAccumulatingSaturating64BitMixedSignednessAccelerated: VkBool32storageTexelBufferOffsetAlignmentBytes: VkDeviceSizestorageTexelBufferOffsetSingleTexelAlignment: VkBool32uniformTexelBufferOffsetAlignmentBytes: VkDeviceSizeuniformTexelBufferOffsetSingleTexelAlignment: VkBool32maxBufferSize: VkDeviceSize

Implementations