VkSwapchainCreateInfoKHR

Struct VkSwapchainCreateInfoKHR 

#[repr(C)]
pub struct VkSwapchainCreateInfoKHR {
Show 18 fields pub sType: VkStructureType, pub pNext: *const void, pub flags: VkSwapchainCreateFlagsKHR, pub surface: VkSurfaceKHR, pub minImageCount: uint32_t, pub imageFormat: VkFormat, pub imageColorSpace: VkColorSpaceKHR, pub imageExtent: VkExtent2D, pub imageArrayLayers: uint32_t, pub imageUsage: VkImageUsageFlags, pub imageSharingMode: VkSharingMode, pub queueFamilyIndexCount: uint32_t, pub pQueueFamilyIndices: *const uint32_t, pub preTransform: VkSurfaceTransformFlagsKHR, pub compositeAlpha: VkCompositeAlphaFlagsKHR, pub presentMode: VkPresentModeKHR, pub clipped: VkBool32, pub oldSwapchain: VkSwapchainKHR,
}
VkSwapchainCreateInfoKHR

Fields

sType: VkStructureTypepNext: *const voidflags: VkSwapchainCreateFlagsKHRsurface: VkSurfaceKHR

The swapchain’s target surface

minImageCount: uint32_t

Minimum number of presentation images the application needs

imageFormat: VkFormat

Format of the presentation images

imageColorSpace: VkColorSpaceKHR

Colorspace of the presentation images

imageExtent: VkExtent2D

Dimensions of the presentation images

imageArrayLayers: uint32_t

Determines the number of views for multiview/stereo presentation

imageUsage: VkImageUsageFlags

Bits indicating how the presentation images will be used

imageSharingMode: VkSharingMode

Sharing mode used for the presentation images

queueFamilyIndexCount: uint32_t

Number of queue families having access to the images in case of concurrent sharing mode

pQueueFamilyIndices: *const uint32_t

Array of queue family indices having access to the images in case of concurrent sharing mode

preTransform: VkSurfaceTransformFlagsKHR

The transform, relative to the device’s natural orientation, applied to the image content prior to presentation

compositeAlpha: VkCompositeAlphaFlagsKHR

The alpha blending mode used when compositing this surface with other surfaces in the window system

presentMode: VkPresentModeKHR

Which presentation mode to use for presents on this swap chain

clipped: VkBool32

Specifies whether presentable images may be affected by window clip regions

oldSwapchain: VkSwapchainKHR

Existing swap chain to replace, if any

Implementations